@@ -57,11 +57,16 @@
 // Libmuon includes
 #include <libmuon/MuonDataSources.h>
 #include <resources/ResourcesModel.h>
-#include <Transaction/TransactionModel.h>
+#include <resources/ResourcesUpdatesModel.h>
+#include <Category/CategoryModel.h>
 #include <Category/Category.h>
+#include <Transaction/TransactionListener.h>
+#include <Transaction/Transaction.h>
+#include <ReviewsBackend/Rating.h>
+#include <ReviewsBackend/AbstractReviewsBackend.h>
+#include <MuonBackendsFactory.h>
 
-Q_DECLARE_METATYPE(ResourcesModel*)
-Q_DECLARE_METATYPE(TransactionModel*)
+Q_DECLARE_METATYPE(ResourcesModel*);
 
 MuonDiscoverMainWindow::MuonDiscoverMainWindow()
     : MuonMainWindow()
@@ -90,8 +95,6 @@ MuonDiscoverMainWindow::MuonDiscoverMainWindow()
     //Here we set up a cache for the screenshots
     m_view->engine()->rootContext()->setContextProperty("resourcesModel",
                                                         qVariantFromValue<ResourcesModel*>(ResourcesModel::global()));
-    m_view->engine()->rootContext()->setContextProperty("transactionModel",
-                                                        qVariantFromValue<TransactionModel*>(TransactionModel::global()));
     m_view->engine()->rootContext()->setContextProperty("app", this);
     m_view->setResizeMode(QDeclarativeView::SizeRootObjectToView);
     
@@ -120,8 +123,18 @@ MuonDiscoverMainWindow::MuonDiscoverMainWindow()
 
 void MuonDiscoverMainWindow::initialize()
 {
-    ResourcesModel *m = ResourcesModel::global();
-    m->integrateMainWindow(this);
+    // Initialize singleton ResourcesModel instance. It will live in the main thread
+    // and all future calls to ResourcesModel::global() will refer to it.
+    Q_ASSERT(ResourcesModel::global() == nullptr);
+    ResourcesModel *m = new ResourcesModel(this);
+
+    MuonBackendsFactory factory;
+    QList<AbstractResourcesBackend*> backends = factory.allBackends();
+
+    foreach(AbstractResourcesBackend* b, backends) {
+        m->addResourcesBackend(b);
+        b->integrateMainWindow(this);
+    }
 }
 
 MuonDiscoverMainWindow::~MuonDiscoverMainWindow()
