@@ -33,6 +33,7 @@
 #include <resources/ResourcesModel.h>
 #include "BreadcrumbWidget/BreadcrumbWidget.h"
 #include "CategoryView/CategoryViewWidget.h"
+#include "ResourceDetailsView/ResourceDetailsView.h"
 
 AvailableView::AvailableView(QWidget *parent)
         : AbstractViewContainer(parent)
@@ -56,3 +57,23 @@ AvailableView::AvailableView(QWidget *parent)
     connect(m_categoryViewWidget, SIGNAL(switchToSubView(AbstractViewBase*)),
             this, SLOT(switchToSubView(AbstractViewBase*)));
 }
+
+void AvailableView::setResource(AbstractResource *res)
+{
+    // Check to see if a view for this app already exists
+    if (m_currentPair.second == res) {
+        QMetaObject::invokeMethod(this, "switchToSubView", Q_ARG(AbstractViewBase*, m_currentPair.first));
+        return;
+    }
+
+    // Create one if not
+    m_detailsView = new ResourceDetailsView(this);
+    m_detailsView->setResource(res);
+    m_currentPair.first = m_detailsView;
+
+    connect(m_detailsView, SIGNAL(destroyed(QObject*)),
+            this, SLOT(onSubViewDestroyed()));
+
+    // Tell our parent that we can exist, so that they can forward it
+    QMetaObject::invokeMethod(this, "registerNewSubView", Q_ARG(AbstractViewBase*, m_detailsView));
+}
