@@ -47,8 +47,8 @@
 #include "../libmuonapt/QAptActions.h"
 
 // Libmuon includes
-#include <Transaction/TransactionModel.h>
 #include <resources/ResourcesModel.h>
+#include <MuonBackendsFactory.h>
 
 // Own includes
 #include "ApplicationLauncher.h"
@@ -63,9 +63,9 @@ enum ViewModelRole {
     /// A role for storing ViewType
     ViewTypeRole = Qt::UserRole + 1,
     /// A role for storing origin filter data
-    OriginFilterRole,
+    OriginFilterRole = Qt::UserRole + 2,
     /// A role for storing state filter data
-    StateFilterRole
+    StateFilterRole = Qt::UserRole + 3
 };
 
 enum ViewType {
@@ -90,6 +90,7 @@ MainWindow::MainWindow()
     , m_launcherMessage(nullptr)
     , m_appLauncher(nullptr)
     , m_progressItem(nullptr)
+    , m_transactionCount(0)
 {
     initGUI();
     QTimer::singleShot(10, this, SLOT(initObject()));
@@ -147,30 +148,39 @@ void MainWindow::initGUI()
 
 void MainWindow::initObject()
 {
-    ResourcesModel *resourcesModel = ResourcesModel::global();
+    // Initialize singleton ResourcesModel instance. It will live in the main thread
+    // and all future calls to ResourcesModel::global() will refer to it.
+    Q_ASSERT(ResourcesModel::global() == nullptr);
+    ResourcesModel *resourcesModel = new ResourcesModel(this);
+    connect(resourcesModel, SIGNAL(transactionAdded(Transaction*)),
+            this, SLOT(transactionAdded()));
+    connect(resourcesModel, SIGNAL(transactionRemoved(Transaction*)),
+            this, SLOT(transactionRemoved()));
 
-    TransactionModel *transModel = TransactionModel::global();
-    connect(transModel, SIGNAL(startingFirstTransaction()),
-            this, SLOT(addProgressItem()));
-    connect(transModel, SIGNAL(lastTransactionFinished()),
-            this, SLOT(removeProgressItem()));
     m_launches = new LaunchListModel(this);
 
-    QVector<AbstractResourcesBackend*> backends = resourcesModel->backends();
+    MuonBackendsFactory f;
+    QList<AbstractResourcesBackend*> backends = f.allBackends();
 
     //TODO: should add the appBackend here too
     for (AbstractResourcesBackend *backend : backends) {
+        resourcesModel->addResourcesBackend(backend);
+        backend->integrateMainWindow(this);
+        
         if(backend->metaObject()->className()==QLatin1String("ApplicationBackend")) {
             m_appBackend = backend;
             connect(m_appBackend, SIGNAL(backendReady()),
                     this, SLOT(populateViews()));
+            connect(m_appBackend, SIGNAL(reloadStarted()), //TODO: use ResourcesModel signals
+                    this, SLOT(removeProgressItem()));
             connect(m_appBackend, SIGNAL(reloadFinished()),
                     this, SLOT(showLauncherMessage()));
+            connect(m_appBackend, SIGNAL(startingFirstTransaction()),
+                    this, SLOT(addProgressItem()));
             connect(m_appBackend, SIGNAL(sourcesEditorFinished()),
                     this, SLOT(sourcesEditorFinished()));
         }
     }
-    resourcesModel->integrateMainWindow(this);
 }
 
 void MainWindow::loadSplitterSizes()
@@ -312,6 +322,8 @@ void MainWindow::populateViews()
     m_viewModel->appendRow(installedItem);
     m_viewModel->appendRow(historyItem);
     selectFirstRow(m_viewSwitcher);
+
+    emit viewsPopulated();
 }
 
 void MainWindow::changeView(const QModelIndex &index)
@@ -432,6 +444,20 @@ void MainWindow::clearMessageActions()
     }
 }
 
+void MainWindow::transactionAdded()
+{
+    m_transactionCount++;
+}
+
+void MainWindow::transactionRemoved()
+{
+    if (m_transactionCount)
+        m_transactionCount--;
+
+    if (!m_transactionCount)
+        removeProgressItem();
+}
+
 void MainWindow::addProgressItem()
 {
     QStandardItem *parentItem = m_viewModel->invisibleRootItem();
@@ -461,3 +487,25 @@ void MainWindow::removeProgressItem()
     m_viewModel->removeRow(m_progressItem->row());
     m_progressItem = nullptr;
 }
+
+void MainWindow::openApplication(const QString &app)
+{
+    setEnabled(false);
+    m_appToBeOpened = app;
+    triggerOpenApplication();
+    if(!m_appToBeOpened.isEmpty())
+        connect(this, SIGNAL(viewsPopulated()), SLOT(triggerOpenApplication()));
+}
+
+void MainWindow::triggerOpenApplication()
+{
+    AbstractResource* app = ResourcesModel::global()->resourceByPackageName(m_appToBeOpened);
+    if(app) {
+        AvailableView *view = qobject_cast<AvailableView *>(m_viewStack->currentWidget());
+        view->setResource(app);
+
+        m_appToBeOpened.clear();
+        disconnect(this, SIGNAL(viewsPopulated()), this, SLOT(triggerOpenApplication()));
+        setEnabled(true);
+    }
+}
