@@ -53,8 +53,11 @@ public:
     MainWindow();
     ~MainWindow();
 
+    void openApplication(const QString &app);
+
 private:
     AbstractResourcesBackend *m_appBackend;
+    QString m_appToBeOpened;
     QSplitter *m_mainWidget;
     QStackedWidget *m_viewStack;
     QWidget *m_busyWidget;
@@ -69,6 +72,8 @@ private:
     ProgressView *m_progressView;
     QStandardItem *m_progressItem;
 
+    int m_transactionCount;
+
 private Q_SLOTS:
     void initGUI();
     void initObject();
@@ -84,8 +89,14 @@ private Q_SLOTS:
     void showAppLauncher();
     void onAppLauncherClosed();
     void clearMessageActions();
+    void transactionAdded();
+    void transactionRemoved();
     void addProgressItem();
     void removeProgressItem();
+    void triggerOpenApplication();
+
+signals:
+    void viewsPopulated();
 };
 
 #endif
