@@ -23,47 +23,39 @@
 #include "resources/ResourcesModel.h"
 #include <KServiceTypeTrader>
 #include <KDebug>
-#include <KCmdLineArgs>
 #include <QPluginLoader>
-#include <QCoreApplication>
 #include <kplugininfo.h>
 
 MuonBackendsFactory::MuonBackendsFactory()
 {}
 
-AbstractResourcesBackend* MuonBackendsFactory::backend(const QString& name) const
+AbstractResourcesBackend* MuonBackendsFactory::backend(const QString& pluginname)
 {
-    QString query = QString("[X-KDE-PluginInfo-Name]=='%1'").arg( name );
+    QString query = QString("[X-KDE-PluginInfo-Name]=='%1'").arg( pluginname );
     KService::List serviceList = KServiceTypeTrader::self()->query( "Muon/Backend", query );
     if(!serviceList.isEmpty()) {
         return backendForPlugin(KPluginInfo(serviceList.first()));
     } else {
-        qWarning() << "Couldn't find the backend: " << name;
+        qWarning() << "Couldn't find the backend: " << pluginname;
     }
     return 0;
 }
 
-QList<AbstractResourcesBackend*> MuonBackendsFactory::allBackends() const
+QList<AbstractResourcesBackend*> MuonBackendsFactory::allBackends()
 {
+    KService::List serviceList = KServiceTypeTrader::self() ->query("Muon/Backend");
+    
     QList<AbstractResourcesBackend*> ret;
-    QSet<QString> whitelist = fetchBackendsWhitelist();
-    if(!whitelist.isEmpty()) {
-        foreach(const QString& b, whitelist)
-            ret += backend(b);
-    } else {
-        KService::List serviceList = KServiceTypeTrader::self()->query("Muon/Backend");
-        
-        foreach(const KService::Ptr& plugin, serviceList) {
-            KPluginInfo info(plugin);
-            if(info.pluginName()=="muon-dummybackend")
-                continue;
+    foreach(const KService::Ptr& plugin, serviceList) {
+        KPluginInfo info(plugin);
+        if(info.pluginName()=="muon-dummybackend")
+            continue;
 
-            AbstractResourcesBackend* b = backendForPlugin(info);
-            if(b) {
-                ret += b;
-            } else {
-                qDebug() << "couldn't load " << info.name();
-            }
+        AbstractResourcesBackend* b = backendForPlugin(info);
+        if(b) {
+            ret += b;
+        } else {
+            qDebug() << "couldn't load " << info.name();
         }
     }
 
@@ -72,23 +64,8 @@ QList<AbstractResourcesBackend*> MuonBackendsFactory::allBackends() const
     return ret;
 }
 
-int MuonBackendsFactory::backendsCount() const
-{
-    int ret = fetchBackendsWhitelist().count();
-    if(ret>0)
-        return ret;
-    
-    KService::List serviceList = KServiceTypeTrader::self() ->query("Muon/Backend");
-    
-    foreach(const KService::Ptr& plugin, serviceList) {
-        KPluginInfo info(plugin);
-        if(info.name()!="muon-dummybackend")
-            ret++;
-    }
-    return ret;
-}
 
-AbstractResourcesBackend* MuonBackendsFactory::backendForPlugin(const KPluginInfo& info) const
+AbstractResourcesBackend* MuonBackendsFactory::backendForPlugin(const KPluginInfo& info)
 {
     QVariantMap args;
     foreach(const QString& prop, info.service()->propertyNames()) {
@@ -113,10 +90,3 @@ AbstractResourcesBackend* MuonBackendsFactory::backendForPlugin(const KPluginInf
     return obj;
 }
 
-QSet<QString> MuonBackendsFactory::fetchBackendsWhitelist() const
-{
-    QSet<QString> whitelist;
-    if(KCmdLineArgs::parsedArgs() && KCmdLineArgs::parsedArgs()->isSet("backends"))
-        whitelist = KCmdLineArgs::parsedArgs()->getOption("backends").split(',').toSet();
-    return whitelist;
-}
