@@ -96,17 +96,21 @@ double dampenedRating(const QVector<int> &ratings, double power = 0.1)
     return sum_scores + 3;
 }
 
-///TODO: improve API
 Rating::Rating(const QVariantMap &data)
+    : Rating(data.value("package_name").toString(), data.value("app_name").toString(),
+             data.value("ratings_total").toULongLong(), data.value("ratings_average").toDouble() * 2, data.value("histogram").toString())
+{
+}
+
+Rating::Rating(const QString& packageName, const QString& appName, int ratingCount, int rating, const QString& histogram)
+    : QObject()
+    , m_packageName(packageName)
+    , m_appName(appName)
+    , m_ratingCount(ratingCount)
+    , m_rating(rating)
+    , m_ratingPoints(0)
+    , m_sortableRating(0)
 {
-    m_packageName = data.value("package_name").toString();
-    m_appName = data.value("app_name").toString();
-    m_ratingCount = data.value("ratings_total").toULongLong();
-    m_rating = data.value("ratings_average").toDouble() * 2;
-    
-    m_sortableRating = 0;
-    m_ratingPoints = 0;
-    QString histogram = data.value("histogram").toString();
     QStringList histo = histogram.mid(1,histogram.size()-2).split(", ");
     QVector<int> spread = QVector<int>();
 
