@@ -23,7 +23,6 @@
 
 #include <resources/AbstractResourcesBackend.h>
 #include "libmuonprivate_export.h"
-#include <Transaction/AddonList.h>
 #include <Transaction/Transaction.h>
 #include <QHash>
 #include <QVariantList>
@@ -45,9 +44,11 @@ public:
     
     virtual void cancelTransaction(AbstractResource* app);
     virtual void removeApplication(AbstractResource* app);
-    virtual void installApplication(AbstractResource* app, AddonList addons);
-    virtual void installApplication(AbstractResource* app) { installApplication(app, AddonList()); }
+    virtual void installApplication(AbstractResource* app, const QHash< QString, bool >& addons);
+    virtual void installApplication(AbstractResource* app) { installApplication(app, QHash<QString,bool>()); }
     virtual AbstractResource* resourceByPackageName(const QString& name) const;
+    virtual QList< Transaction* > transactions() const;
+    virtual QPair< TransactionStateTransition, Transaction* > currentTransactionState() const;
     virtual int updatesCount() const;
     virtual AbstractReviewsBackend* reviewsBackend() const;
     virtual QStringList searchPackageName(const QString& searchText);
