@@ -18,15 +18,18 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-// Qt includes
+#include "KNSBackend.h"
+#include "KNSResource.h"
+#include "KNSReviews.h"
+#include "KNSUpdater.h"
+#include <Transaction/Transaction.h>
+
 #include <QDebug>
 #include <QFileInfo>
 
-// Attica includes
 #include <attica/content.h>
 #include <attica/providermanager.h>
 
-// KDE includes
 #include <knewstuff3/downloadmanager.h>
 #include <KStandardDirs>
 #include <KConfigGroup>
@@ -36,16 +39,6 @@
 #include <KLocalizedString>
 #include <KAboutData>
 
-// Libmuon includes
-#include "Transaction/Transaction.h"
-#include "Transaction/TransactionModel.h"
-
-// Own includes
-#include "KNSBackend.h"
-#include "KNSResource.h"
-#include "KNSReviews.h"
-#include <resources/StandardBackendUpdater.h>
-
 K_PLUGIN_FACTORY(MuonKNSBackendFactory, registerPlugin<KNSBackend>(); )
 K_EXPORT_PLUGIN(MuonKNSBackendFactory(KAboutData("muon-knsbackend","muon-knsbackend",ki18n("KNewStuff Backend"),"0.1",ki18n("Install KNewStuff data in your system"), KAboutData::License_GPL)))
 
@@ -68,7 +61,7 @@ KNSBackend::KNSBackend(QObject* parent, const QVariantList& args)
     , m_page(0)
     , m_reviews(new KNSReviews(this))
     , m_fetching(true)
-    , m_updater(new StandardBackendUpdater(this))
+    , m_updater(new KNSUpdater(this))
 {
     const QVariantMap info = args.first().toMap();
     
@@ -162,9 +155,7 @@ void KNSBackend::receivedContents(Attica::BaseJob* job)
     }
     QString filename = QFileInfo(m_name).fileName();
     foreach(const Attica::Content& c, contents) {
-        KNSResource* r = new KNSResource(c, filename, m_iconName, this);
-        m_resourcesByName.insert(c.id(), r);
-        connect(r, SIGNAL(stateChanged()), SIGNAL(updatesCountChanged()));
+        m_resourcesByName.insert(c.id(), new KNSResource(c, filename, m_iconName, this));
     }
     m_page++;
     Attica::ListJob<Attica::Content>* jj =
@@ -206,27 +197,25 @@ void KNSBackend::cancelTransaction(AbstractResource* app)
 
 void KNSBackend::removeApplication(AbstractResource* app)
 {
-    Transaction* t = new Transaction(this, app, Transaction::RemoveRole);
-    TransactionModel *transModel = TransactionModel::global();
-    transModel->addTransaction(t);
+    Transaction* t = new Transaction(app, RemoveApp);
+    emit transactionAdded(t);
     KNSResource* r = qobject_cast<KNSResource*>(app);
     Q_ASSERT(r->entry());
     m_manager->uninstallEntry(*r->entry());
-    transModel->removeTransaction(t);
+    emit transactionRemoved(t);
 }
 
 void KNSBackend::installApplication(AbstractResource* app)
 {
-    Transaction* t = new Transaction(this, app, Transaction::InstallRole);
-    TransactionModel *transModel = TransactionModel::global();
-    transModel->addTransaction(t);
+    Transaction* t = new Transaction(app, InstallApp);
+    emit transactionAdded(t);
     KNSResource* r = qobject_cast<KNSResource*>(app);
     Q_ASSERT(r->entry());
     m_manager->installEntry(*r->entry());
-    transModel->removeTransaction(t);
+    emit transactionRemoved(t);
 }
 
-void KNSBackend::installApplication(AbstractResource* app, AddonList)
+void KNSBackend::installApplication(AbstractResource* app, const QHash< QString, bool >&)
 {
     installApplication(app);
 }
@@ -236,6 +225,16 @@ AbstractResource* KNSBackend::resourceByPackageName(const QString& name) const
     return m_resourcesByName[name];
 }
 
+QList<Transaction*> KNSBackend::transactions() const
+{
+    return QList<Transaction*>();
+}
+
+QPair<TransactionStateTransition, Transaction*> KNSBackend::currentTransactionState() const
+{
+    return QPair<TransactionStateTransition, Transaction*>(FinishedCommitting, 0);
+}
+
 int KNSBackend::updatesCount() const
 {
     int ret = 0;
@@ -246,7 +245,7 @@ int KNSBackend::updatesCount() const
     return ret;
 }
 
-QList<AbstractResource*> KNSBackend::upgradeablePackages() const
+QList<AbstractResource*> KNSBackend::upgradeablePackages()
 {
     QList<AbstractResource*> ret;
     foreach(AbstractResource* r, m_resourcesByName) {
