@@ -21,20 +21,15 @@
 #ifndef KNSBACKEND_H
 #define KNSBACKEND_H
 
-// KDE includes
+#include <resources/AbstractResourcesBackend.h>
 #include <knewstuff3/entry.h>
-
-// Attica includes
 #include <attica/category.h>
 #include <attica/provider.h>
 
-// Libmuon includes
-#include <resources/AbstractResourcesBackend.h>
-#include "Transaction/AddonList.h"
-
 #include "libmuonprivate_export.h"
 
 class KConfigGroup;
+class KNSUpdater;
 class KNSReviews;
 namespace KNS3 { class DownloadManager; }
 namespace Attica {
@@ -53,8 +48,10 @@ public:
     virtual void cancelTransaction(AbstractResource* app);
     virtual void removeApplication(AbstractResource* app);
     virtual void installApplication(AbstractResource* app);
-    virtual void installApplication(AbstractResource* app, AddonList addons);
+    virtual void installApplication(AbstractResource* app, const QHash< QString, bool >& addons);
     virtual AbstractResource* resourceByPackageName(const QString& name) const;
+    virtual QList< Transaction* > transactions() const;
+    virtual QPair< TransactionStateTransition, Transaction* > currentTransactionState() const;
     virtual int updatesCount() const;
     virtual AbstractReviewsBackend* reviewsBackend() const;
     virtual QStringList searchPackageName(const QString& searchText);
@@ -64,7 +61,7 @@ public:
     bool isValid() const;
     bool isFetching() const;
     Attica::Provider* provider() { return &m_provider; }
-    QList<AbstractResource*> upgradeablePackages() const;
+    QList<AbstractResource*> upgradeablePackages();
 
 public slots:
     void receivedEntries(const KNS3::Entry::List& entry);
@@ -87,7 +84,7 @@ private:
     QString m_name;
     bool m_fetching;
     QString m_iconName;
-    AbstractBackendUpdater* m_updater;
+    KNSUpdater* m_updater;
 };
 
 #endif // KNSBACKEND_H
