@@ -21,8 +21,6 @@
 #include "AbstractResource.h"
 #include "AbstractResourcesBackend.h"
 #include <KLocalizedString>
-#include <KGlobal>
-#include <KLocale>
 
 AbstractResource::AbstractResource(AbstractResourcesBackend* parent)
     : QObject(parent)
@@ -87,13 +85,3 @@ QString AbstractResource::status()
     }
     return QString();
 }
-
-bool AbstractResource::isFromSecureOrigin() const
-{
-    return false;
-}
-
-QString AbstractResource::sizeDescription()
-{
-    return KGlobal::locale()->formatByteSize(downloadSize());
-}
