@@ -21,19 +21,13 @@
 #include "ResourcesModel.h"
 
 #include <KGlobal>
-#include <KDebug>
 
-#include "AbstractResource.h"
 #include "resources/AbstractResourcesBackend.h"
+#include "AbstractResource.h"
 #include <ReviewsBackend/Rating.h>
 #include <ReviewsBackend/AbstractReviewsBackend.h>
 #include <Transaction/Transaction.h>
-#include <MuonBackendsFactory.h>
-#include <MuonMainWindow.h>
-#include "Transaction/TransactionModel.h"
 #include <QDebug>
-#include <QCoreApplication>
-#include <QThread>
 
 static const KCatalogLoader loader("libmuon");
 
@@ -41,18 +35,14 @@ ResourcesModel *ResourcesModel::s_self = nullptr;
 
 ResourcesModel *ResourcesModel::global()
 {
-    if(!s_self)
-        s_self = new ResourcesModel;
     return s_self;
 }
 
-ResourcesModel::ResourcesModel(QObject* parent, bool load)
+ResourcesModel::ResourcesModel(QObject* parent)
     : QAbstractListModel(parent)
-    , m_initializingBackends(0)
-    , m_mainwindow(0)
 {
-    Q_ASSERT(!s_self);
-    Q_ASSERT(QCoreApplication::instance()->thread()==QThread::currentThread());
+    if (!s_self)
+        s_self = this;
 
     QHash< int, QByteArray > roles = roleNames();
     roles[NameRole] = "name";
@@ -75,49 +65,39 @@ ResourcesModel::ResourcesModel(QObject* parent, bool load)
     roles.remove(Qt::EditRole);
     roles.remove(Qt::WhatsThisRole);
     setRoleNames(roles);
-
-    connect(TransactionModel::global(), SIGNAL(transactionAdded(Transaction*)), SLOT(resourceChangedByTransaction(Transaction*)));
-    connect(TransactionModel::global(), SIGNAL(transactionRemoved(Transaction*)), SLOT(resourceChangedByTransaction(Transaction*)));
-    if(load)
-        QMetaObject::invokeMethod(this, "registerAllBackends", Qt::QueuedConnection);
 }
 
-ResourcesModel::ResourcesModel(const QString& backendName, QObject* parent)
-    : ResourcesModel(parent, false)
+void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* resources)
 {
-    Q_ASSERT(!s_self);
-    s_self = this;
-    registerBackendByName(backendName);
-}
-
-ResourcesModel::~ResourcesModel()
-{
-    qDeleteAll(m_backends);
-}
-
-void ResourcesModel::addResourcesBackend(AbstractResourcesBackend* backend)
-{
-    Q_ASSERT(!m_backends.contains(backend));
-    QVector<AbstractResource*> newResources = backend->allResources();
+    Q_ASSERT(!m_backends.contains(resources));
+    QVector<AbstractResource*> newResources = resources->allResources();
     if(!newResources.isEmpty()) {
         int current = rowCount();
         beginInsertRows(QModelIndex(), current, current+newResources.size());
-        m_backends += backend;
+        m_backends += resources;
         m_resources.append(newResources);
         endInsertRows();
     } else {
-        m_backends += backend;
+        m_backends += resources;
         m_resources.append(newResources);
     }
-    if(m_mainwindow)
-        backend->integrateMainWindow(m_mainwindow);
     
-    connect(backend, SIGNAL(backendReady()), SLOT(resetCaller()));
-    connect(backend, SIGNAL(reloadStarted()), SLOT(cleanCaller()));
-    connect(backend, SIGNAL(reloadFinished()), SLOT(resetCaller()));
-    connect(backend, SIGNAL(updatesCountChanged()), SIGNAL(updatesCountChanged()));
-    connect(backend, SIGNAL(allDataChanged()), SLOT(updateCaller()));
-    connect(backend, SIGNAL(searchInvalidated()), SIGNAL(searchInvalidated()));
+    connect(resources, SIGNAL(backendReady()), SLOT(resetCaller()));
+    connect(resources, SIGNAL(reloadStarted()), SLOT(cleanCaller()));
+    connect(resources, SIGNAL(reloadFinished()), SLOT(resetCaller()));
+    connect(resources, SIGNAL(updatesCountChanged()), SIGNAL(updatesCountChanged()));
+    connect(resources, SIGNAL(allDataChanged()), SLOT(updateCaller()));
+    connect(resources, SIGNAL(searchInvalidated()), SIGNAL(searchInvalidated()));
+    
+    connect(resources, SIGNAL(transactionAdded(Transaction*)), SIGNAL(transactionAdded(Transaction*)));
+    connect(resources, SIGNAL(transactionCancelled(Transaction*)), SIGNAL(transactionCancelled(Transaction*)));
+    connect(resources, SIGNAL(transactionProgressed(Transaction*,int)), SIGNAL(transactionProgressed(Transaction*,int)));
+    connect(resources, SIGNAL(transactionRemoved(Transaction*)), SIGNAL(transactionRemoved(Transaction*)));
+    connect(resources, SIGNAL(transactionsEvent(TransactionStateTransition,Transaction*)), SIGNAL(transactionsEvent(TransactionStateTransition,Transaction*)));
+    
+    connect(this, SIGNAL(transactionAdded(Transaction*)), SLOT(transactionChanged(Transaction*)));
+    connect(this, SIGNAL(transactionRemoved(Transaction*)), SLOT(transactionChanged(Transaction*)));
+    connect(this, SIGNAL(transactionCancelled(Transaction*)), SLOT(transactionChanged(Transaction*)));
 
     emit backendsChanged();
 }
@@ -159,8 +139,18 @@ QVariant ResourcesModel::data(const QModelIndex& index, int role) const
 
     AbstractResource* resource = resourceAt(index.row());
     switch(role) {
-        case ActiveRole:
-            return TransactionModel::global()->transactionFromResource(resource) != nullptr;
+        case ActiveRole: {
+            Transaction* t = nullptr;
+
+            for (Transaction *trans : resource->backend()->transactions()) {
+                if (trans->resource() == resource) {
+                    t = trans;
+                    break;
+                }
+            }
+
+            return (t != nullptr);
+        }
         case ApplicationRole:
             return qVariantFromValue<QObject*>(resource);
         case RatingPointsRole:
@@ -177,8 +167,9 @@ QVariant ResourcesModel::data(const QModelIndex& index, int role) const
             return QVariant();
         default: {
             QByteArray roleText = roleNames().value(role);
-            Q_ASSERT(!roleText.isEmpty());
-            if(resource->metaObject()->indexOfProperty(roleText) < 0) {
+            if(roleText.isEmpty())
+                return QVariant();
+            else if(resource->metaObject()->indexOfProperty(roleText) < 0) {
                 qDebug() << "unknown role:" << role << roleText;
                 return QVariant();
             } else
@@ -202,7 +193,6 @@ int ResourcesModel::rowCount(const QModelIndex& parent) const
 
 void ResourcesModel::cleanCaller()
 {
-    m_initializingBackends++;
     AbstractResourcesBackend* backend = qobject_cast<AbstractResourcesBackend*>(sender());
     Q_ASSERT(backend);
     int pos = m_backends.indexOf(backend);
@@ -245,9 +235,6 @@ void ResourcesModel::resetCaller()
         endInsertRows();
         emit updatesCountChanged();
     }
-    m_initializingBackends--;
-    if(m_initializingBackends==0)
-        emit allInitialized();
 }
 
 void ResourcesModel::updateCaller()
@@ -299,9 +286,9 @@ void ResourcesModel::installApplication(AbstractResource* app)
     app->backend()->installApplication(app);
 }
 
-void ResourcesModel::installApplication(AbstractResource* app, AddonList addons)
+void ResourcesModel::installApplication(AbstractResource* app, const QHash< QString, bool >& state)
 {
-    app->backend()->installApplication(app, addons);
+    app->backend()->installApplication(app, state);
 }
 
 void ResourcesModel::removeApplication(AbstractResource* app)
@@ -314,6 +301,12 @@ void ResourcesModel::cancelTransaction(AbstractResource* app)
     app->backend()->cancelTransaction(app);
 }
 
+void ResourcesModel::transactionChanged(Transaction* t)
+{
+    QModelIndex idx = resourceIndex(t->resource());
+    dataChanged(idx, idx);
+}
+
 QMap<int, QVariant> ResourcesModel::itemData(const QModelIndex& index) const
 {
     QMap<int, QVariant> ret;
@@ -323,42 +316,3 @@ QMap<int, QVariant> ResourcesModel::itemData(const QModelIndex& index) const
     }
     return ret;
 }
-
-void ResourcesModel::registerAllBackends()
-{
-    MuonBackendsFactory f;
-    m_initializingBackends += f.backendsCount();
-    if(m_initializingBackends==0) {
-        kWarning() << "Couldn't find any backends";
-        emit allInitialized();
-    } else {
-        QList<AbstractResourcesBackend*> backends = f.allBackends();
-        foreach(AbstractResourcesBackend* b, backends) {
-            addResourcesBackend(b);
-        }
-    }
-}
-
-void ResourcesModel::registerBackendByName(const QString& name)
-{
-    MuonBackendsFactory f;
-    addResourcesBackend(f.backend(name));
-    m_initializingBackends++;
-}
-
-void ResourcesModel::integrateMainWindow(MuonMainWindow* w)
-{
-    Q_ASSERT(w->thread()==thread());
-    m_mainwindow = w;
-    setParent(w);
-    foreach(AbstractResourcesBackend* b, m_backends) {
-        b->integrateMainWindow(w);
-    }
-}
-
-void ResourcesModel::resourceChangedByTransaction(Transaction* t)
-{
-    QModelIndex idx = resourceIndex(t->resource());
-    if(idx.isValid())
-        dataChanged(idx, idx);
-}
