@@ -46,10 +46,11 @@
 
 // LibQApt includes
 #include <LibQApt/Backend>
+#include <LibQApt/DependencyInfo>
 #include <LibQApt/MarkingErrorInfo>
 
 // Own includes
-#include "../libmuon/ChangesDialog.h"
+#include "../libmuonapt/ChangesDialog.h"
 #include "DetailsWidget.h"
 #include "MuonSettings.h"
 #include "PackageModel.h"
@@ -621,7 +622,7 @@ void PackageWidget::showBrokenReason(QApt::Package *package)
 QString PackageWidget::digestReason(QApt::Package *pkg, const QApt::MarkingErrorInfo &info)
 {
     QString reason;
-    QString relation = pkgCache::DepType(info.errorInfo().dependencyType());
+    QString relation = QApt::DependencyInfo::typeName(info.errorInfo().dependencyType());
 
     reason += '\t';
 
@@ -648,6 +649,8 @@ QString PackageWidget::digestReason(QApt::Package *pkg, const QApt::MarkingError
                         "%1: %2, but it is a virtual package",
                         relation, pkg->name());
         break;
+    default:
+        break;
     }
 
     reason += '\n';
