@@ -27,6 +27,10 @@
 
 #include <KIcon>
 
+namespace QApt {
+class Package;
+}
+
 class AbstractResource;
 class UpdateItem
 {
@@ -64,6 +68,7 @@ public:
     qint64 size() const;
     Qt::CheckState checked() const;
     ItemType type() const;
+    QApt::Package* retrievePackage() const;
 
 private:
     AbstractResource *m_app;
