@@ -29,9 +29,11 @@
 #include <KLocale>
 #include <KDebug>
 
+// LibQApt includes
+#include <LibQApt/Package>
+
 // Own includes
 #include "UpdateItem.h"
-#include <resources/AbstractResource.h>
 
 #define ICON_SIZE KIconLoader::SizeSmallMedium
 
@@ -213,6 +215,21 @@ UpdateItem* UpdateModel::itemFromIndex(const QModelIndex &index) const
      return m_rootItem;
 }
 
+void UpdateModel::updateCheckStates()
+{
+    for (UpdateItem *item : m_rootItem->children()) {
+        for (UpdateItem *subItem : item->children()) {
+            QApt::Package *pkg = subItem->retrievePackage();
+            if (!pkg)
+                continue;
+
+            subItem->setChecked(pkg->state() & QApt::Package::ToInstall);
+        }
+    }
+
+    packageChanged();
+}
+
 void UpdateModel::addItem(UpdateItem *item)
 {
     beginInsertRows(QModelIndex(), m_rootItem->childCount(), m_rootItem->childCount());
@@ -250,48 +267,3 @@ void UpdateModel::packageChanged()
     // We don't know what changed or not, so say everything changed
     emit dataChanged(index(0, 0), QModelIndex());
 }
-
-void UpdateModel::addResources(const QList< AbstractResource* >& resources)
-{
-    UpdateItem *securityItem = new UpdateItem(i18nc("@item:inlistbox", "Important Security Updates"),
-                                              KIcon("security-medium"));
-
-    UpdateItem *appItem = new UpdateItem(i18nc("@item:inlistbox", "Application Updates"),
-                                          KIcon("applications-other"));
-
-    UpdateItem *systemItem = new UpdateItem(i18nc("@item:inlistbox", "System Updates"),
-                                             KIcon("applications-system"));
-
-    foreach(AbstractResource* res, resources) {
-        UpdateItem *updateItem = new UpdateItem(res);
-        if (res->isFromSecureOrigin()) {
-            securityItem->appendChild(updateItem);
-        } else if(!res->isTechnical()) {
-            appItem->appendChild(updateItem);
-        } else {
-            systemItem->appendChild(updateItem);
-        }
-    }
-
-    // Add populated items to the model
-    if (securityItem->childCount()) {
-        securityItem->sort();
-        addItem(securityItem);
-    } else {
-        delete securityItem;
-    }
-
-    if (appItem->childCount()) {
-        appItem->sort();
-        addItem(appItem);
-    } else {
-        delete appItem;
-    }
-
-    if (systemItem->childCount()) {
-        systemItem->sort();
-        addItem(systemItem);
-    } else {
-        delete systemItem;
-    }
-}
