@@ -23,7 +23,10 @@
 
 #include <QtGui/QStackedWidget>
 
-class ResourcesUpdatesModel;
+// LibQApt includes
+#include <LibQApt/Globals>
+#include <LibQApt/Package>
+
 class KMessageWidget;
 class AbstractResource;
 class AbstractResourcesBackend;
@@ -33,6 +36,11 @@ class QStandardItemModel;
 class QTreeView;
 
 class KPixmapSequenceOverlayPainter;
+
+namespace QApt {
+    class Backend;
+}
+
 class UpdateModel;
 
 class UpdaterWidget : public QStackedWidget
@@ -42,6 +50,10 @@ public:
     explicit UpdaterWidget(QWidget *parent = 0);
 
 private:
+    QApt::Package* retrievePackage(AbstractResource* res);
+
+    QApt::Backend *m_backend;
+    QApt::CacheState m_oldCacheState;
     UpdateModel *m_updateModel;
 
     QTreeView *m_updateView;
@@ -49,24 +61,25 @@ private:
     QLabel *m_updateStatusIcon;
     QLabel *m_notifyTitle;
     QLabel *m_notifyDesc;
-    ResourcesUpdatesModel* m_updatesBackends;
+    AbstractResourcesBackend* m_appsBackend;
     KMessageWidget* m_upgradesWidget;
 
 public Q_SLOTS:
-    void setBackend(ResourcesUpdatesModel* backend);
-    void activityChanged();
+    void setBackend(AbstractResourcesBackend* backend);
+    void reload();
 
 private Q_SLOTS:
     void populateUpdateModel();
+    void checkApps(QList<AbstractResource*> apps, bool checked);
+    void checkChanges(const QHash<QApt::Package::State, QApt::PackageList> &removals);
     void selectionChanged(const QItemSelection &selected,
                           const QItemSelection &deselected);
     void checkAllMarked();
     void checkUpToDate();
     void markAllPackagesForUpgrade();
-    void checkApps(const QList<AbstractResource*>& apps, bool checked);
 
 signals:
-    void selectedResourceChanged(AbstractResource* res);
+    void selectedPackageChanged(QApt::Package *Package);
 };
 
 #endif // UPDATERWIDGET_H
