@@ -30,7 +30,7 @@
 static const char description[] =
     I18N_NOOP("An update manager");
 
-static const char version[] = "1.9.80";
+static const char version[] = "1.9.97";
 
 int main(int argc, char **argv)
 {
@@ -41,9 +41,7 @@ int main(int argc, char **argv)
     about.setProductName("muon/updater");
 
     KCmdLineArgs::init(argc, argv, &about);
-    KCmdLineOptions options;
-    options.add("backends <names>", ki18n("List all the backends we'll want to have loaded, separated by coma ','."));
-    KCmdLineArgs::addCmdLineOptions( options );
+
     if (!KUniqueApplication::start()) {
         fprintf(stderr, "Update Manager is already running!\n");
         return 0;
@@ -51,7 +49,6 @@ int main(int argc, char **argv)
 
     KUniqueApplication app;
     app.disableSessionManagement();
-    KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
     MainWindow *mainWindow = new MainWindow;
     mainWindow->show();
